@@ -468,8 +468,24 @@ char *HasHash(const char *a, const struct Hash *h)
 
 void ClearHash(struct Hash *h)
 {
+    int i;
+    struct HashEntry *he, *next;
     if (h && h->Index)
+    {
+        /* Free all the memory */
+        for ( i = 0; i < HASH_SIZE; ++i )
+        {
+            he = h->Index[i];
+            while ( he )
+            {
+                next = he->Next;
+                free( he );
+                he = next;
+            }
+        }
+        /* Reset the hash table */
         memset(h->Index, '\0', HASH_SIZE * sizeof(struct HashEntry *));
+    }
 }
 
 /*
@@ -522,8 +538,13 @@ int InsertWord(const char *Word, struct WordList *WL)
 
 void ClearWord(struct WordList *WL)
 {
+    char *Word;
     if (WL)
     {
+        while ( (Word = StkPop( &WL->Stack )) )
+        {
+            free(Word);
+        }
         WL->Stack.Used = 0;
         WL->MaxLen = 0;
         ClearHash(&WL->Hash);
@@ -726,6 +747,8 @@ char *FGetsStk(char *Dest, unsigned long len, struct Stack *stack)
 
             fn = StkPop(stack);
             fclose(fn->fh);
+            if ( fn->Name != NULL )
+                free(fn->Name);
             free(fn);
             HasSeenLong = 0;
         }
@@ -745,7 +768,13 @@ const char *CurStkName(struct Stack *stack)
     else
     {
         if ((fn = StkTop(stack)))
-            return (LastName = fn->Name);
+        {
+            if ( stack->Used == 1 && strlen(LastName) == 0 && fn->Name )
+            {
+                LastName = strdup(fn->Name);
+            }
+            return (fn->Name);
+        }
         else
             return (LastName);
     }
