@@ -150,9 +150,9 @@ struct ErrInfo *TopErr(struct Stack *Stack);
 struct ErrInfo *PopErr(struct Stack *Stack);
 struct ErrInfo *TopMatch(struct Stack *Stack, char *String);
 
-long BrackIndex(char const c);
-void AddBracket(char const c);
-char MatchBracket(char const);
+long BrackIndex(const char c);
+void AddBracket(const char c);
+char MatchBracket(const char c);
 
 
 
@@ -173,6 +173,12 @@ char *mystrdup(const char *String);
 int strcasecmp(char *a, char *b);
 #endif
 
+#if !(defined HAVE_DECL_STPCPY && HAVE_DECL_STPCPY)
+static inline char * stpcpy(char *dest, const char *src)
+{
+    return strcpy(dest, src) + strlen(src);
+}
+#endif
 
 
 #endif /* UTILITY_H */
